==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/ledger/vo/LedgerExamineVO.java <==
package com.ejianc.business.probuilddiary.ledger.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 日志台账-原材料检验、时间、试块及见证取样送检等情况（取样员）
 *
 * @author baipengyan
 */
public class LedgerExamineVO extends BaseVO {
	private static final long serialVersionUID = 2065052385694805270L;

	private Long personId; // 个人日志id
	private Long moldId; // 工作类型id
	private String moldName; // 工作类型名称
	private String moldCode; // 工作类型编码
	private String makeName; // 试块制作情况名称
	private String inspectName; // 试块送检情况名称
	private String examineName; // 现场检测名称名称
	private BigDecimal examineNum; // 数量
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private Long ledgerId; // 日志台账id
	private String templateContent; // 模版内容，#分隔开的字段名称，例如：commitUserName#commitDate#workMemo，输出：张三 16：00 完成1号楼基础部分基坑支护
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getMoldId() {
		return moldId;
	}

	public void setMoldId(Long moldId) {
		this.moldId = moldId;
	}

	public String getMoldName() {
		return moldName;
	}

	public void setMoldName(String moldName) {
		this.moldName = moldName;
	}

	public String getMoldCode() {
		return moldCode;
	}

	public void setMoldCode(String moldCode) {
		this.moldCode = moldCode;
	}

	public String getMakeName() {
		return makeName;
	}

	public void setMakeName(String makeName) {
		this.makeName = makeName;
	}

	public String getInspectName() {
		return inspectName;
	}

	public void setInspectName(String inspectName) {
		this.inspectName = inspectName;
	}

	public String getExamineName() {
		return examineName;
	}

	public void setExamineName(String examineName) {
		this.examineName = examineName;
	}

	public BigDecimal getExamineNum() {
		return examineNum;
	}

	public void setExamineNum(BigDecimal examineNum) {
		this.examineNum = examineNum;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getTemplateContent() {
		return templateContent;
	}

	public void setTemplateContent(String templateContent) {
		this.templateContent = templateContent;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-api-3.0.0-20250526.024810-164-sources.jar: com/ejianc/business/probuilddiary/ledger/vo/LedgerExamineVO.java <==
package com.ejianc.business.probuilddiary.ledger.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 日志台账-检验试验情况（取样员）
 *
 * @author baipengyan
 */
public class LedgerExamineVO extends BaseVO {
	private static final long serialVersionUID = 2065052385694805270L;

	private Long personId; // 个人日志id
	private Long moldId; // 工作类型id
	private String moldName; // 工作类型名称
	private String moldCode; // 工作类型编码
	private String makeName; // 试块制作情况名称
	private String inspectName; // 试块送检情况名称
	private String examineName; // 现场检测名称名称
	private BigDecimal examineNum; // 数量
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private Long ledgerId; // 日志台账id
	private String templateContent; // 模版内容，#分隔开的字段名称，例如：commitUserName#commitDate#workMemo，输出：张三 16：00 完成1号楼基础部分基坑支护
	private String fileType; // 文件类型
	private String logNumber; // 日志项编码
	private Boolean projectManagerFlag; // 项目经理标识
	private String examineMemo; // 工作描述

	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getMoldId() {
		return moldId;
	}

	public void setMoldId(Long moldId) {
		this.moldId = moldId;
	}

	public String getMoldName() {
		return moldName;
	}

	public void setMoldName(String moldName) {
		this.moldName = moldName;
	}

	public String getMoldCode() {
		return moldCode;
	}

	public void setMoldCode(String moldCode) {
		this.moldCode = moldCode;
	}

	public String getMakeName() {
		return makeName;
	}

	public void setMakeName(String makeName) {
		this.makeName = makeName;
	}

	public String getInspectName() {
		return inspectName;
	}

	public void setInspectName(String inspectName) {
		this.inspectName = inspectName;
	}

	public String getExamineName() {
		return examineName;
	}

	public void setExamineName(String examineName) {
		this.examineName = examineName;
	}

	public BigDecimal getExamineNum() {
		return examineNum;
	}

	public void setExamineNum(BigDecimal examineNum) {
		this.examineNum = examineNum;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getTemplateContent() {
		return templateContent;
	}

	public void setTemplateContent(String templateContent) {
		this.templateContent = templateContent;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public String getLogNumber() {
		return logNumber;
	}

	public void setLogNumber(String logNumber) {
		this.logNumber = logNumber;
	}

	public Boolean getProjectManagerFlag() {
		return projectManagerFlag;
	}

	public void setProjectManagerFlag(Boolean projectManagerFlag) {
		this.projectManagerFlag = projectManagerFlag;
	}

	public String getExamineMemo() {
		return examineMemo;
	}

	public void setExamineMemo(String examineMemo) {
		this.examineMemo = examineMemo;
	}
}
